==> ejc-production-impl-3.0.0-20220505.023604-95-sources.jar: com/ejianc/business/production/controller/ProductiontasktransportController.java <==
package com.ejianc.business.production.controller;

import java.io.Serializable;

import com.alibaba.fastjson.JSONArray;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.production.bean.ProductiontaskEntity;
import com.ejianc.business.production.bean.ProductiontasktransportEntity;
import com.ejianc.business.production.utils.DateUtils;
import com.ejianc.business.production.vo.ProductiontasktransportVO;
import com.ejianc.business.production.service.IProductiontaskService;
import com.ejianc.business.production.service.IProductiontasktransportService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.framework.skeleton.refer.util.ReferObjectUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

/**
 * 任务单运输信息
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("productiontasktransport")
public class ProductiontasktransportController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "task-transport";//此处需要根据实际修改

    @Autowired
    private IProductiontasktransportService service;

    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IProductiontaskService productiontaskService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ProductiontasktransportVO> saveOrUpdate(@RequestBody ProductiontasktransportVO saveOrUpdateVO) {
    	ProductiontasktransportEntity entity = BeanMapper.map(saveOrUpdateVO, ProductiontasktransportEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        ProductiontaskEntity productiontaskEntity = productiontaskService.selectById(entity.getTaskId());
//        校验车牌号分配是否符合逻辑
        /**
         * 此车牌号同一工程下的不同任务单可以同一天分配
         */

//        QueryWrapper query=new QueryWrapper();
//        query.eq("shippers_vehicle_code",entity.getShippersVehicleCode());
//        List<ProductiontasktransportEntity> list = service.list(query);
//        if (list.size()>0){
//            for (ProductiontasktransportEntity tasktransportEntity : list) {
//                if (DateUtils.isSameDay(tasktransportEntity.getTransportTime(),new Date())){
//                    throw new BusinessException("此车牌号今天已分配任务单");
//                }
//            }
//        }
        /**
         * 校验车辆运输重量
         */
        BigDecimal sumCount=new BigDecimal("0");
        QueryWrapper query2=new QueryWrapper();
        query2.eq("task_id",entity.getTaskId());
        List<ProductiontasktransportEntity> taskList = service.list(query2);
        if (taskList.size()>0){
            for (ProductiontasktransportEntity Entity : taskList) {
                if (!String.valueOf(Entity.getId()).equals(String.valueOf(entity.getId()))){
                    sumCount=sumCount.add(Entity.getTransportCount());
                }
            }
        }

        BigDecimal subtract=productiontaskEntity.getThisQuantity().subtract(sumCount);
        if (entity.getTransportCount().compareTo(subtract)==1){
            throw new BusinessException("运送数量不能大于"+subtract.setScale(2).toString()+"吨");
        }else if (entity.getTransportCount().compareTo(subtract)==0){
            productiontaskEntity.setTaskStatus(3);
            productiontaskService.saveOrUpdate(productiontaskEntity,false);
        }
    	service.saveOrUpdate(entity, false);
    	ProductiontasktransportVO vo = BeanMapper.map(entity, ProductiontasktransportVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ProductiontasktransportVO> queryDetail(Long id) {
    	ProductiontasktransportEntity entity = service.selectById(id);
    	ProductiontasktransportVO vo = BeanMapper.map(entity, ProductiontasktransportVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ProductiontasktransportVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (ProductiontasktransportVO vo : vos) {
                ProductiontaskEntity entity = productiontaskService.selectById(vo.getTaskId());
                entity.setTaskStatus(2);
                productiontaskService.saveOrUpdate(entity,false);
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(ProductiontasktransportVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ProductiontasktransportVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<ProductiontasktransportEntity> page = service.queryPage(param,false);
        IPage<ProductiontasktransportVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ProductiontasktransportVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ProductiontasktransportEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Productiontasktransport-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refProductiontasktransportData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ProductiontasktransportVO>> refProductiontasktransportData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            String status = _con.getString("status");
            if (status!=null) {
                param.getParams().put("transport_statue", new Parameter(QueryParam.EQ, status));
            }
        }
        IPage<ProductiontasktransportEntity> page = service.queryPage(param,false);
        IPage<ProductiontasktransportVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        List<ProductiontasktransportVO> records = BeanMapper.mapList(page.getRecords(), ProductiontasktransportVO.class);
        if (ListUtil.isNotEmpty(records)){
            records.forEach(e->{
                try {
                    JSONArray equcode = ReferObjectUtil.getReferEntityValue(e.getTaskId().toString(), "ProductiontaskRef");
                    if(!equcode.isEmpty()){
                        e.setTaskCode(((JSONObject)equcode.get(0)).getString("billCode"));
                        e.setCustomerManageId(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("customerId"))?Long.valueOf(((JSONObject)equcode.get(0)).getString("customerId")):null);
                        e.setProjectId(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("projectId"))?Long.valueOf(((JSONObject)equcode.get(0)).getString("projectId")):null);
                        e.setProductId(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("productId"))?Long.valueOf(((JSONObject)equcode.get(0)).getString("productId")):null);
                        e.setWorksiteId(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("worksiteId"))?Long.valueOf(((JSONObject)equcode.get(0)).getString("worksiteId")):null);
                        e.setUnitId(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("unitId"))?Long.valueOf(((JSONObject)equcode.get(0)).getString("unitId")):null);
                        e.setDistance(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("distance"))?new BigDecimal(((JSONObject)equcode.get(0)).getString("distance")):null);
                        e.setCustomerManageName(((JSONObject)equcode.get(0)).getString("customerName"));
                        e.setProjectName(((JSONObject)equcode.get(0)).getString("projectName"));
                        e.setProductName(((JSONObject)equcode.get(0)).getString("productName"));
                        e.setWorksiteName(((JSONObject)equcode.get(0)).getString("worksiteName"));
                        e.setUnitName(((JSONObject)equcode.get(0)).getString("unitName"));
                        e.setTransportMethod(((JSONObject)equcode.get(0)).getString("transportMethod"));
                    }
                } catch (Exception exception) {
                    exception.printStackTrace();
                }
            });
        }
        pageData.setRecords(records);

        return CommonResponse.success("查询参照数据成功！",pageData);
     }


}

==> ejc-production-impl-3.0.0-20220519.105729-107-sources.jar: com/ejianc/business/production/controller/ProductiontasktransportController.java <==
package com.ejianc.business.production.controller;

import java.io.Serializable;

import com.alibaba.fastjson.JSONArray;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.production.bean.ProductiontaskEntity;
import com.ejianc.business.production.bean.ProductiontasktransportEntity;
import com.ejianc.business.production.utils.DateUtils;
import com.ejianc.business.production.vo.ProductiontasktransportVO;
import com.ejianc.business.production.service.IProductiontaskService;
import com.ejianc.business.production.service.IProductiontasktransportService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.framework.skeleton.refer.util.ReferObjectUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

/**
 * 任务单运输信息
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("productiontasktransport")
public class ProductiontasktransportController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "task-transport";//此处需要根据实际修改

    @Autowired
    private IProductiontasktransportService service;

    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IProductiontaskService productiontaskService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ProductiontasktransportVO> saveOrUpdate(@RequestBody ProductiontasktransportVO saveOrUpdateVO) {
    	ProductiontasktransportEntity entity = BeanMapper.map(saveOrUpdateVO, ProductiontasktransportEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        ProductiontaskEntity productiontaskEntity = productiontaskService.selectById(entity.getTaskId());
//        校验车牌号分配是否符合逻辑
        /**
         * 此车牌号同一工程下的不同任务单可以同一天分配
         */

//        QueryWrapper query=new QueryWrapper();
//        query.eq("shippers_vehicle_code",entity.getShippersVehicleCode());
//        List<ProductiontasktransportEntity> list = service.list(query);
//        if (list.size()>0){
//            for (ProductiontasktransportEntity tasktransportEntity : list) {
//                if (DateUtils.isSameDay(tasktransportEntity.getTransportTime(),new Date())){
//                    throw new BusinessException("此车牌号今天已分配任务单");
//                }
//            }
//        }
        /**
         * 校验车辆运输重量
         */
        BigDecimal sumCount=new BigDecimal("0");
        QueryWrapper query2=new QueryWrapper();
        query2.eq("task_id",entity.getTaskId());
        List<ProductiontasktransportEntity> taskList = service.list(query2);
        if (taskList.size()>0){
            for (ProductiontasktransportEntity Entity : taskList) {
                if (!String.valueOf(Entity.getId()).equals(String.valueOf(entity.getId()))){
                    sumCount=sumCount.add(Entity.getTransportCount());
                }
            }
        }

        BigDecimal subtract=productiontaskEntity.getThisQuantity().subtract(sumCount);
        if (entity.getTransportCount().compareTo(subtract)==1){
            throw new BusinessException("运送数量不能大于"+subtract.setScale(2).toString()+"吨");
        }else if (entity.getTransportCount().compareTo(subtract)==0){
            productiontaskEntity.setTaskStatus(3);
            productiontaskService.saveOrUpdate(productiontaskEntity,false);
        }
    	service.saveOrUpdate(entity, false);
    	ProductiontasktransportVO vo = BeanMapper.map(entity, ProductiontasktransportVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ProductiontasktransportVO> queryDetail(Long id) {
    	ProductiontasktransportEntity entity = service.selectById(id);
    	ProductiontasktransportVO vo = BeanMapper.map(entity, ProductiontasktransportVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ProductiontasktransportVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (ProductiontasktransportVO vo : vos) {
                ProductiontaskEntity entity = productiontaskService.selectById(vo.getTaskId());
                entity.setTaskStatus(2);
                productiontaskService.saveOrUpdate(entity,false);
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(ProductiontasktransportVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ProductiontasktransportVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<ProductiontasktransportEntity> page = service.queryPage(param,false);
        IPage<ProductiontasktransportVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ProductiontasktransportVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ProductiontasktransportEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Productiontasktransport-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refProductiontasktransportData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ProductiontasktransportVO>> refProductiontasktransportData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            String status = _con.getString("status");
            if (status!=null) {
                param.getParams().put("transport_statue", new Parameter(QueryParam.EQ, status));
            }
        }
        IPage<ProductiontasktransportEntity> page = service.queryPage(param,false);
        IPage<ProductiontasktransportVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        List<ProductiontasktransportVO> records = BeanMapper.mapList(page.getRecords(), ProductiontasktransportVO.class);
        if (ListUtil.isNotEmpty(records)){
            records.forEach(e->{
                try {
                    JSONArray equcode = ReferObjectUtil.getReferEntityValue(e.getTaskId().toString(), "ProductiontaskRef");
                    if(!equcode.isEmpty()){
                        e.setTaskCode(((JSONObject)equcode.get(0)).getString("billCode"));
                        e.setCustomerManageId(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("customerId"))?Long.valueOf(((JSONObject)equcode.get(0)).getString("customerId")):null);
                        e.setProjectId(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("projectId"))?Long.valueOf(((JSONObject)equcode.get(0)).getString("projectId")):null);
                        e.setProductId(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("productId"))?Long.valueOf(((JSONObject)equcode.get(0)).getString("productId")):null);
                        e.setWorksiteId(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("worksiteId"))?Long.valueOf(((JSONObject)equcode.get(0)).getString("worksiteId")):null);
                        e.setUnitId(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("unitId"))?Long.valueOf(((JSONObject)equcode.get(0)).getString("unitId")):null);
                        e.setDistance(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("distance"))?new BigDecimal(((JSONObject)equcode.get(0)).getString("distance")):null);
                        e.setCustomerManageName(((JSONObject)equcode.get(0)).getString("customerName"));
                        e.setProjectName(((JSONObject)equcode.get(0)).getString("projectName"));
                        e.setProductName(((JSONObject)equcode.get(0)).getString("productName"));
                        e.setWorksiteName(((JSONObject)equcode.get(0)).getString("worksiteName"));
                        e.setPrintCustomerName(((JSONObject)equcode.get(0)).getString("printCustomerName"));
                        e.setPrintProductName(((JSONObject)equcode.get(0)).getString("printProductName"));
                        e.setPrintWorksiteName(((JSONObject)equcode.get(0)).getString("printWorksiteName"));
                        e.setPrintSupplyName(((JSONObject)equcode.get(0)).getString("printSupplyName"));
                        e.setUnitName(((JSONObject)equcode.get(0)).getString("unitName"));
                        e.setTransportMethod(((JSONObject)equcode.get(0)).getString("transportMethod"));
                        e.setOrderName(((JSONObject)equcode.get(0)).getString("orderName"));
                        e.setOrderMobile(((JSONObject)equcode.get(0)).getString("orderMobile"));
                        e.setTransportRoute(((JSONObject)equcode.get(0)).getString("transportRoute"));
                    }
                } catch (Exception exception) {
                    exception.printStackTrace();
                }
            });
        }
        pageData.setRecords(records);

        return CommonResponse.success("查询参照数据成功！",pageData);
     }


}
